==> mutual_credit-5.0.5.tar.gz: mutual_credit/src/Form/WalletAddForm.php <==
<?php

namespace Drupal\mcapi\Form;

use Drupal\mcapi\Entity\Wallet;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form builder to create a new wallet for a given ContentEntity.
 */
class WalletAddForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wallet_add_form';
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $holder = $this->entity->holder->entity; // cannot be null.
    $form['#title'] = $this->t("New wallet for @entity_type '%title'",
      [
        '@entity_type' => $holder->getEntityType()->getLabel(),
        '%title' => $holder->label(),
      ]
    );
    $form = parent::form($form, $form_state);
    // @todo dont suggest values that already exist.
    $form['name']['widget'][0]['value']['#default_value'] = $this->entity->holder->entity->label();
    $form['name']['widget'][0]['value']['#placeholder'] = $this->entity->holder->entity->label() . ' ('.t('suggested').')';
    $form['holder']['#access'] = FALSE;
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = t('Create');
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $this->entity->save();
    $form_state->setRedirectUrl($this->entity->toUrl('edit-form'));
    $this->messenger()->addStatus($this->t('The wallet was created'));
  }

    /**
   * {@inheritdoc}
   */
  public function getEntityFromRouteMatch(RouteMatchInterface $route_match, $entity_type_id) {
    $params = $route_match->getParameters()->all();
    $values = ['holder' => reset($params)];
    return Wallet::create($values);
  }

}

==> mutual_credit-5.1.0.tar.gz: mutual_credit/src/Form/WalletAddForm.php <==
<?php

namespace Drupal\mcapi\Form;

use Drupal\mcapi\Entity\Wallet;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form builder to create a new wallet for a given ContentEntity.
 */
class WalletAddForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wallet_add_form';
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $holder = $this->entity->holder->entity; // cannot be null.
    $form['#title'] = $this->t("New wallet for @entity_type '%title'",
      [
        '@entity_type' => $holder->getEntityType()->getLabel(),
        '%title' => $holder->label(),
      ]
    );
    $form = parent::form($form, $form_state);
    $form['name']['widget'][0]['value']['#placeholder'] = $this->entity->holder->entity->label() . ' ('.$this->t('suggested').')';
    $form['holder']['#access'] = FALSE;
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = $this->t('Create');
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $this->entity->save();
    $form_state->setRedirectUrl($this->entity->toUrl('edit-form'));
    $this->messenger()->addStatus($this->t('The wallet was created'));
  }

    /**
   * {@inheritdoc}
   */
  public function getEntityFromRouteMatch(RouteMatchInterface $route_match, $entity_type_id) {
    $params = $route_match->getParameters()->all();
    $values = ['holder' => reset($params)];
    return Wallet::create($values);
  }

}
